==> peony-extensions_3.14.1.0.orig.tar.gz: peony-extensions-3.14.1.0/peony-drive-rename/translations/peony-drive-rename_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="en_US">
<context>
    <name>Peony::DriveRename</name>
    <message>
        <source>drive rename</source>
        <translation type="vanished">设备重命名</translation>
    </message>
    <message>
        <location filename="../drive-rename.cpp" line="163"/>
        <location filename="../drive-rename.cpp" line="175"/>
        <source>Rename</source>
        <translation>重命名</translation>
    </message>
    <message>
        <location filename="../drive-rename.cpp" line="175"/>
        <source>Device name:</source>
        <translation>设备名：</translation>
    </message>
    <message>
        <location filename="../drive-rename.cpp" line="179"/>
        <location filename="../drive-rename.cpp" line="187"/>
        <location filename="../drive-rename.cpp" line="193"/>
        <location filename="../drive-rename.cpp" line="206"/>
        <source>Warning</source>
        <translation>警告</translation>
    </message>
    <message>
        <location filename="../drive-rename.cpp" line="179"/>
        <source>Renaming cannot start with a decimal point, Please re-enter!</source>
        <translation>重命名时不支持首字符为小数点，请重新输入!</translation>
    </message>
    <message>
        <location filename="../drive-rename.cpp" line="187"/>
        <source>The device name exceeds the character limit, rename failed!</source>
        <translation>设备名超过字符限制，重命名失败!</translation>
    </message>
    <message>
        <location filename="../drive-rename.cpp" line="193"/>
        <source>Renaming will unmount the device. Do you want to continue?</source>
        <translation>重命名将会卸载设备，是否继续？</translation>
    </message>
    <message>
        <location filename="../drive-rename.cpp" line="206"/>
        <source>The device may not support the rename operation, rename failed!</source>
        <translation>可能设备不支持重命名操作，重命名失败！</translation>
    </message>
    <message>
        <source>Failed to rename!</source>
        <translation type="vanished">重命名失败！</translation>
    </message>
</context>
<context>
    <name>Peony::DriveRenamePlugin</name>
    <message>
        <location filename="../driverenameplugin.h" line="21"/>
        <source>drive rename</source>
        <translation type="unfinished">设备重命名</translation>
    </message>
</context>
<context>
    <name>Peony::DriverAction</name>
    <message>
        <source>Send to a removable device</source>
        <translation type="vanished">发送到移动设备</translation>
    </message>
</context>
<context>
    <name>Peony::SendToPlugin</name>
    <message>
        <source>Send to a removable device</source>
        <translation type="vanished">发送到移动设备</translation>
    </message>
</context>
</TS>

==> peony-extensions_4.0.0.0.orig.tar.gz: peony-extensions-4.0.0.0/peony-drive-rename/translations/peony-drive-rename_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="en_US">
<context>
    <name>Peony::DriveRename</name>
    <message>
        <source>drive rename</source>
        <translation type="vanished">设备重命名</translation>
    </message>
    <message>
        <location filename="../drive-rename.cpp" line="166"/>
        <location filename="../drive-rename.cpp" line="178"/>
        <source>Rename</source>
        <translation>重命名</translation>
    </message>
    <message>
        <location filename="../drive-rename.cpp" line="178"/>
        <source>Device name:</source>
        <translation>设备名：</translation>
    </message>
    <message>
        <location filename="../drive-rename.cpp" line="182"/>
        <location filename="../drive-rename.cpp" line="190"/>
        <location filename="../drive-rename.cpp" line="196"/>
        <source>Warning</source>
        <translation>警告</translation>
    </message>
    <message>
        <location filename="../drive-rename.cpp" line="182"/>
        <source>Renaming cannot start with a decimal point, Please re-enter!</source>
        <translation>重命名时不支持首字符为小数点，请重新输入!</translation>
    </message>
    <message>
        <location filename="../drive-rename.cpp" line="190"/>
        <source>The device name exceeds the character limit, rename failed!</source>
        <translation>设备名超过字符限制，重命名失败!</translation>
    </message>
    <message>
        <location filename="../drive-rename.cpp" line="196"/>
        <source>Renaming will unmount the device. Do you want to continue?</source>
        <translation>重命名将会卸载设备，是否继续？</translation>
    </message>
    <message>
        <source>The device may not support the rename operation, rename failed!</source>
        <translation type="vanished">可能设备不支持重命名操作，重命名失败！</translation>
    </message>
    <message>
        <source>Failed to rename!</source>
        <translation type="vanished">重命名失败！</translation>
    </message>
</context>
<context>
    <name>Peony::DriveRenamePlugin</name>
    <message>
        <location filename="../driverenameplugin.h" line="21"/>
        <source>drive rename</source>
        <translation>设备重命名</translation>
    </message>
</context>
<context>
    <name>Peony::DriverAction</name>
    <message>
        <source>Send to a removable device</source>
        <translation type="vanished">发送到移动设备</translation>
    </message>
</context>
<context>
    <name>Peony::SendToPlugin</name>
    <message>
        <source>Send to a removable device</source>
        <translation type="vanished">发送到移动设备</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../drive-rename.cpp" line="314"/>
        <source>Warning</source>
        <translation>警告</translation>
    </message>
    <message>
        <location filename="../drive-rename.cpp" line="314"/>
        <source>The device may not support the rename operation, rename failed!</source>
        <translation>可能设备不支持重命名操作，重命名失败！</translation>
    </message>
</context>
</TS>
